# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.oracledatabase_v1.types import (
    autonomous_database_character_set,
    autonomous_db_backup,
    autonomous_db_version,
    db_node,
    db_server,
    db_system_shape,
    entitlement,
    exadata_infra,
    gi_version,
    vm_cluster,
)
from google.cloud.oracledatabase_v1.types import (
    autonomous_database as gco_autonomous_database,
)

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "ListCloudExadataInfrastructuresRequest",
        "ListCloudExadataInfrastructuresResponse",
        "GetCloudExadataInfrastructureRequest",
        "CreateCloudExadataInfrastructureRequest",
        "DeleteCloudExadataInfrastructureRequest",
        "ListCloudVmClustersRequest",
        "ListCloudVmClustersResponse",
        "GetCloudVmClusterRequest",
        "CreateCloudVmClusterRequest",
        "DeleteCloudVmClusterRequest",
        "ListEntitlementsRequest",
        "ListEntitlementsResponse",
        "ListDbServersRequest",
        "ListDbServersResponse",
        "ListDbNodesRequest",
        "ListDbNodesResponse",
        "ListGiVersionsRequest",
        "ListGiVersionsResponse",
        "ListDbSystemShapesRequest",
        "ListDbSystemShapesResponse",
        "OperationMetadata",
        "ListAutonomousDatabasesRequest",
        "ListAutonomousDatabasesResponse",
        "GetAutonomousDatabaseRequest",
        "CreateAutonomousDatabaseRequest",
        "DeleteAutonomousDatabaseRequest",
        "RestoreAutonomousDatabaseRequest",
        "GenerateAutonomousDatabaseWalletRequest",
        "GenerateAutonomousDatabaseWalletResponse",
        "ListAutonomousDbVersionsRequest",
        "ListAutonomousDbVersionsResponse",
        "ListAutonomousDatabaseCharacterSetsRequest",
        "ListAutonomousDatabaseCharacterSetsResponse",
        "ListAutonomousDatabaseBackupsRequest",
        "ListAutonomousDatabaseBackupsResponse",
    },
)


class ListCloudExadataInfrastructuresRequest(proto.Message):
    r"""The request for ``CloudExadataInfrastructures.List``.

    Attributes:
        parent (str):
            Required. The parent value for
            CloudExadataInfrastructure in the following
            format: projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 Exadata
            infrastructures will be returned. The maximum
            value is 1000; values above 1000 will be coerced
            to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListCloudExadataInfrastructuresResponse(proto.Message):
    r"""The response for ``CloudExadataInfrastructures.list``.

    Attributes:
        cloud_exadata_infrastructures (MutableSequence[google.cloud.oracledatabase_v1.types.CloudExadataInfrastructure]):
            The list of Exadata Infrastructures.
        next_page_token (str):
            A token for fetching next page of response.
    """

    @property
    def raw_page(self):
        return self

    cloud_exadata_infrastructures: MutableSequence[
        exadata_infra.CloudExadataInfrastructure
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=exadata_infra.CloudExadataInfrastructure,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetCloudExadataInfrastructureRequest(proto.Message):
    r"""The request for ``CloudExadataInfrastructure.Get``.

    Attributes:
        name (str):
            Required. The name of the Cloud Exadata Infrastructure in
            the following format:
            projects/{project}/locations/{location}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateCloudExadataInfrastructureRequest(proto.Message):
    r"""The request for ``CloudExadataInfrastructure.Create``.

    Attributes:
        parent (str):
            Required. The parent value for
            CloudExadataInfrastructure in the following
            format: projects/{project}/locations/{location}.
        cloud_exadata_infrastructure_id (str):
            Required. The ID of the Exadata Infrastructure to create.
            This value is restricted to
            (^`a-z <[a-z0-9-]{0,61}[a-z0-9]>`__?$) and must be a maximum
            of 63 characters in length. The value must start with a
            letter and end with a letter or a number.
        cloud_exadata_infrastructure (google.cloud.oracledatabase_v1.types.CloudExadataInfrastructure):
            Required. Details of the Exadata
            Infrastructure instance to create.
        request_id (str):
            Optional. An optional ID to identify the
            request. This value is used to identify
            duplicate requests. If you make a request with
            the same request ID and the original request is
            still in progress or completed, the server
            ignores the second request. This prevents
            clients from accidentally creating duplicate
            commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    cloud_exadata_infrastructure_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    cloud_exadata_infrastructure: exadata_infra.CloudExadataInfrastructure = (
        proto.Field(
            proto.MESSAGE,
            number=3,
            message=exadata_infra.CloudExadataInfrastructure,
        )
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=4,
    )


class DeleteCloudExadataInfrastructureRequest(proto.Message):
    r"""The request for ``CloudExadataInfrastructure.Delete``.

    Attributes:
        name (str):
            Required. The name of the Cloud Exadata Infrastructure in
            the following format:
            projects/{project}/locations/{location}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}.
        request_id (str):
            Optional. An optional ID to identify the
            request. This value is used to identify
            duplicate requests. If you make a request with
            the same request ID and the original request is
            still in progress or completed, the server
            ignores the second request. This prevents
            clients from accidentally creating duplicate
            commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
        force (bool):
            Optional. If set to true, all VM clusters for
            this Exadata Infrastructure will be deleted. An
            Exadata Infrastructure can only be deleted once
            all its VM clusters have been deleted.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class ListCloudVmClustersRequest(proto.Message):
    r"""The request for ``CloudVmCluster.List``.

    Attributes:
        parent (str):
            Required. The name of the parent in the
            following format:
            projects/{project}/locations/{location}.
        page_size (int):
            Optional. The number of VM clusters to
            return. If unspecified, at most 50 VM clusters
            will be returned. The maximum value is 1,000.
        page_token (str):
            Optional. A token identifying the page of
            results the server returns.
        filter (str):
            Optional. An expression for filtering the
            results of the request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListCloudVmClustersResponse(proto.Message):
    r"""The response for ``CloudVmCluster.List``.

    Attributes:
        cloud_vm_clusters (MutableSequence[google.cloud.oracledatabase_v1.types.CloudVmCluster]):
            The list of VM Clusters.
        next_page_token (str):
            A token to fetch the next page of results.
    """

    @property
    def raw_page(self):
        return self

    cloud_vm_clusters: MutableSequence[vm_cluster.CloudVmCluster] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=vm_cluster.CloudVmCluster,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetCloudVmClusterRequest(proto.Message):
    r"""The request for ``CloudVmCluster.Get``.

    Attributes:
        name (str):
            Required. The name of the Cloud VM Cluster in the following
            format:
            projects/{project}/locations/{location}/cloudVmClusters/{cloud_vm_cluster}.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateCloudVmClusterRequest(proto.Message):
    r"""The request for ``CloudVmCluster.Create``.

    Attributes:
        parent (str):
            Required. The name of the parent in the
            following format:
            projects/{project}/locations/{location}.
        cloud_vm_cluster_id (str):
            Required. The ID of the VM Cluster to create. This value is
            restricted to (^`a-z <[a-z0-9-]{0,61}[a-z0-9]>`__?$) and
            must be a maximum of 63 characters in length. The value must
            start with a letter and end with a letter or a number.
        cloud_vm_cluster (google.cloud.oracledatabase_v1.types.CloudVmCluster):
            Required. The resource being created
        request_id (str):
            Optional. An optional ID to identify the
            request. This value is used to identify
            duplicate requests. If you make a request with
            the same request ID and the original request is
            still in progress or completed, the server
            ignores the second request. This prevents
            clients from accidentally creating duplicate
            commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    cloud_vm_cluster_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    cloud_vm_cluster: vm_cluster.CloudVmCluster = proto.Field(
        proto.MESSAGE,
        number=3,
        message=vm_cluster.CloudVmCluster,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=4,
    )


class DeleteCloudVmClusterRequest(proto.Message):
    r"""The request for ``CloudVmCluster.Delete``.

    Attributes:
        name (str):
            Required. The name of the Cloud VM Cluster in the following
            format:
            projects/{project}/locations/{location}/cloudVmClusters/{cloud_vm_cluster}.
        request_id (str):
            Optional. An optional ID to identify the
            request. This value is used to identify
            duplicate requests. If you make a request with
            the same request ID and the original request is
            still in progress or completed, the server
            ignores the second request. This prevents
            clients from accidentally creating duplicate
            commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
        force (bool):
            Optional. If set to true, all child resources
            for the VM Cluster will be deleted. A VM Cluster
            can only be deleted once all its child resources
            have been deleted.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class ListEntitlementsRequest(proto.Message):
    r"""The request for ``Entitlement.List``.

    Attributes:
        parent (str):
            Required. The parent value for the
            entitlement in the following format:
            projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, a maximum of 50
            entitlements will be returned. The maximum value
            is 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListEntitlementsResponse(proto.Message):
    r"""The response for ``Entitlement.List``.

    Attributes:
        entitlements (MutableSequence[google.cloud.oracledatabase_v1.types.Entitlement]):
            The list of Entitlements
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    entitlements: MutableSequence[entitlement.Entitlement] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=entitlement.Entitlement,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListDbServersRequest(proto.Message):
    r"""The request for ``DbServer.List``.

    Attributes:
        parent (str):
            Required. The parent value for database
            server in the following format:
            projects/{project}/locations/{location}/cloudExadataInfrastructures/{cloudExadataInfrastructure}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, a maximum of 50 db
            servers will be returned. The maximum value is
            1000; values above 1000 will be reset to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListDbServersResponse(proto.Message):
    r"""The response for ``DbServer.List``.

    Attributes:
        db_servers (MutableSequence[google.cloud.oracledatabase_v1.types.DbServer]):
            The list of database servers.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    db_servers: MutableSequence[db_server.DbServer] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=db_server.DbServer,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListDbNodesRequest(proto.Message):
    r"""The request for ``DbNode.List``.

    Attributes:
        parent (str):
            Required. The parent value for database node
            in the following format:
            projects/{project}/locations/{location}/cloudVmClusters/{cloudVmCluster}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 db nodes will
            be returned. The maximum value is 1000; values
            above 1000 will be coerced to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the node should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListDbNodesResponse(proto.Message):
    r"""The response for ``DbNode.List``.

    Attributes:
        db_nodes (MutableSequence[google.cloud.oracledatabase_v1.types.DbNode]):
            The list of DB Nodes
        next_page_token (str):
            A token identifying a page of results the
            node should return.
    """

    @property
    def raw_page(self):
        return self

    db_nodes: MutableSequence[db_node.DbNode] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=db_node.DbNode,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListGiVersionsRequest(proto.Message):
    r"""The request for ``GiVersion.List``.

    Attributes:
        parent (str):
            Required. The parent value for Grid
            Infrastructure Version in the following format:
            Format: projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, a maximum of 50 Oracle
            Grid Infrastructure (GI) versions will be
            returned. The maximum value is 1000; values
            above 1000 will be reset to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListGiVersionsResponse(proto.Message):
    r"""The response for ``GiVersion.List``.

    Attributes:
        gi_versions (MutableSequence[google.cloud.oracledatabase_v1.types.GiVersion]):
            The list of Oracle Grid Infrastructure (GI)
            versions.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    gi_versions: MutableSequence[gi_version.GiVersion] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gi_version.GiVersion,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListDbSystemShapesRequest(proto.Message):
    r"""The request for ``DbSystemShape.List``.

    Attributes:
        parent (str):
            Required. The parent value for Database
            System Shapes in the following format:
            projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 database
            system shapes will be returned. The maximum
            value is 1000; values above 1000 will be coerced
            to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListDbSystemShapesResponse(proto.Message):
    r"""The response for ``DbSystemShape.List``.

    Attributes:
        db_system_shapes (MutableSequence[google.cloud.oracledatabase_v1.types.DbSystemShape]):
            The list of Database System shapes.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    db_system_shapes: MutableSequence[
        db_system_shape.DbSystemShape
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=db_system_shape.DbSystemShape,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class OperationMetadata(proto.Message):
    r"""Represents the metadata of the long-running operation.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the operation was
            created.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the operation finished
            running.
        target (str):
            Output only. Server-defined resource path for
            the target of the operation.
        verb (str):
            Output only. Name of the verb executed by the
            operation.
        status_message (str):
            Output only. The status of the operation.
        requested_cancellation (bool):
            Output only. Identifies whether the user has requested
            cancellation of the operation. Operations that have been
            cancelled successfully have [Operation.error][] value with a
            [google.rpc.Status.code][google.rpc.Status.code] of 1,
            corresponding to ``Code.CANCELLED``.
        api_version (str):
            Output only. API version used to start the
            operation.
        percent_complete (float):
            Output only. An estimated percentage of the
            operation that has been completed at a given
            moment of time, between 0 and 100.
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    target: str = proto.Field(
        proto.STRING,
        number=3,
    )
    verb: str = proto.Field(
        proto.STRING,
        number=4,
    )
    status_message: str = proto.Field(
        proto.STRING,
        number=5,
    )
    requested_cancellation: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    api_version: str = proto.Field(
        proto.STRING,
        number=7,
    )
    percent_complete: float = proto.Field(
        proto.DOUBLE,
        number=8,
    )


class ListAutonomousDatabasesRequest(proto.Message):
    r"""The request for ``AutonomousDatabase.List``.

    Attributes:
        parent (str):
            Required. The parent value for the Autonomous
            Database in the following format:
            projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 Autonomous
            Database will be returned. The maximum value is
            1000; values above 1000 will be coerced to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
        filter (str):
            Optional. An expression for filtering the
            results of the request.
        order_by (str):
            Optional. An expression for ordering the
            results of the request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListAutonomousDatabasesResponse(proto.Message):
    r"""The response for ``AutonomousDatabase.List``.

    Attributes:
        autonomous_databases (MutableSequence[google.cloud.oracledatabase_v1.types.AutonomousDatabase]):
            The list of Autonomous Databases.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    autonomous_databases: MutableSequence[
        gco_autonomous_database.AutonomousDatabase
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gco_autonomous_database.AutonomousDatabase,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetAutonomousDatabaseRequest(proto.Message):
    r"""The request for ``AutonomousDatabase.Get``.

    Attributes:
        name (str):
            Required. The name of the Autonomous Database in the
            following format:
            projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateAutonomousDatabaseRequest(proto.Message):
    r"""The request for ``AutonomousDatabase.Create``.

    Attributes:
        parent (str):
            Required. The name of the parent in the
            following format:
            projects/{project}/locations/{location}.
        autonomous_database_id (str):
            Required. The ID of the Autonomous Database to create. This
            value is restricted to
            (^`a-z <[a-z0-9-]{0,61}[a-z0-9]>`__?$) and must be a maximum
            of 63 characters in length. The value must start with a
            letter and end with a letter or a number.
        autonomous_database (google.cloud.oracledatabase_v1.types.AutonomousDatabase):
            Required. The Autonomous Database being
            created.
        request_id (str):
            Optional. An optional ID to identify the
            request. This value is used to identify
            duplicate requests. If you make a request with
            the same request ID and the original request is
            still in progress or completed, the server
            ignores the second request. This prevents
            clients from accidentally creating duplicate
            commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    autonomous_database_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    autonomous_database: gco_autonomous_database.AutonomousDatabase = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gco_autonomous_database.AutonomousDatabase,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=4,
    )


class DeleteAutonomousDatabaseRequest(proto.Message):
    r"""The request for ``AutonomousDatabase.Delete``.

    Attributes:
        name (str):
            Required. The name of the resource in the following format:
            projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.
        request_id (str):
            Optional. An optional ID to identify the
            request. This value is used to identify
            duplicate requests. If you make a request with
            the same request ID and the original request is
            still in progress or completed, the server
            ignores the second request. This prevents
            clients from accidentally creating duplicate
            commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class RestoreAutonomousDatabaseRequest(proto.Message):
    r"""The request for ``AutonomousDatabase.Restore``.

    Attributes:
        name (str):
            Required. The name of the Autonomous Database in the
            following format:
            projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.
        restore_time (google.protobuf.timestamp_pb2.Timestamp):
            Required. The time and date to restore the
            database to.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    restore_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )


class GenerateAutonomousDatabaseWalletRequest(proto.Message):
    r"""The request for ``AutonomousDatabase.GenerateWallet``.

    Attributes:
        name (str):
            Required. The name of the Autonomous Database in the
            following format:
            projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.
        type_ (google.cloud.oracledatabase_v1.types.GenerateType):
            Optional. The type of wallet generation for
            the Autonomous Database. The default value is
            SINGLE.
        is_regional (bool):
            Optional. True when requesting regional
            connection strings in PDB connect info,
            applicable to cross-region Data Guard only.
        password (str):
            Required. The password used to encrypt the
            keys inside the wallet. The password must be a
            minimum of 8 characters.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    type_: gco_autonomous_database.GenerateType = proto.Field(
        proto.ENUM,
        number=2,
        enum=gco_autonomous_database.GenerateType,
    )
    is_regional: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    password: str = proto.Field(
        proto.STRING,
        number=4,
    )


class GenerateAutonomousDatabaseWalletResponse(proto.Message):
    r"""The response for ``AutonomousDatabase.GenerateWallet``.

    Attributes:
        archive_content (bytes):
            Output only. The base64 encoded wallet files.
    """

    archive_content: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )


class ListAutonomousDbVersionsRequest(proto.Message):
    r"""The request for ``AutonomousDbVersion.List``.

    Attributes:
        parent (str):
            Required. The parent value for the Autonomous
            Database in the following format:
            projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 Autonomous DB
            Versions will be returned. The maximum value is
            1000; values above 1000 will be coerced to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListAutonomousDbVersionsResponse(proto.Message):
    r"""The response for ``AutonomousDbVersion.List``.

    Attributes:
        autonomous_db_versions (MutableSequence[google.cloud.oracledatabase_v1.types.AutonomousDbVersion]):
            The list of Autonomous Database versions.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    autonomous_db_versions: MutableSequence[
        autonomous_db_version.AutonomousDbVersion
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=autonomous_db_version.AutonomousDbVersion,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListAutonomousDatabaseCharacterSetsRequest(proto.Message):
    r"""The request for ``AutonomousDatabaseCharacterSet.List``.

    Attributes:
        parent (str):
            Required. The parent value for the Autonomous
            Database in the following format:
            projects/{project}/locations/{location}.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 Autonomous DB
            Character Sets will be returned. The maximum
            value is 1000; values above 1000 will be coerced
            to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
        filter (str):
            Optional. An expression for filtering the results of the
            request. Only the **character_set_type** field is supported
            in the following format:
            ``character_set_type="{characterSetType}"``. Accepted values
            include ``DATABASE`` and ``NATIONAL``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListAutonomousDatabaseCharacterSetsResponse(proto.Message):
    r"""The response for ``AutonomousDatabaseCharacterSet.List``.

    Attributes:
        autonomous_database_character_sets (MutableSequence[google.cloud.oracledatabase_v1.types.AutonomousDatabaseCharacterSet]):
            The list of Autonomous Database Character
            Sets.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    autonomous_database_character_sets: MutableSequence[
        autonomous_database_character_set.AutonomousDatabaseCharacterSet
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=autonomous_database_character_set.AutonomousDatabaseCharacterSet,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListAutonomousDatabaseBackupsRequest(proto.Message):
    r"""The request for ``AutonomousDatabaseBackup.List``.

    Attributes:
        parent (str):
            Required. The parent value for
            ListAutonomousDatabaseBackups in the following
            format: projects/{project}/locations/{location}.
        filter (str):
            Optional. An expression for filtering the results of the
            request. Only the **autonomous_database_id** field is
            supported in the following format:
            ``autonomous_database_id="{autonomous_database_id}"``. The
            accepted values must be a valid Autonomous Database ID,
            limited to the naming restrictions of the ID:
            ^\ `a-z <[a-z0-9-]{0,61}[a-z0-9]>`__?$). The ID must start
            with a letter, end with a letter or a number, and be a
            maximum of 63 characters.
        page_size (int):
            Optional. The maximum number of items to
            return. If unspecified, at most 50 Autonomous DB
            Backups will be returned. The maximum value is
            1000; values above 1000 will be coerced to 1000.
        page_token (str):
            Optional. A token identifying a page of
            results the server should return.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=5,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListAutonomousDatabaseBackupsResponse(proto.Message):
    r"""The response for ``AutonomousDatabaseBackup.List``.

    Attributes:
        autonomous_database_backups (MutableSequence[google.cloud.oracledatabase_v1.types.AutonomousDatabaseBackup]):
            The list of Autonomous Database Backups.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
    """

    @property
    def raw_page(self):
        return self

    autonomous_database_backups: MutableSequence[
        autonomous_db_backup.AutonomousDatabaseBackup
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=autonomous_db_backup.AutonomousDatabaseBackup,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import dayofweek_pb2  # type: ignore
from google.type import month_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.oracledatabase_v1.types import common

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "CloudExadataInfrastructure",
        "CloudExadataInfrastructureProperties",
        "MaintenanceWindow",
    },
)


class CloudExadataInfrastructure(proto.Message):
    r"""Represents CloudExadataInfrastructure resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/CloudExadataInfrastructure/

    Attributes:
        name (str):
            Identifier. The name of the Exadata Infrastructure resource
            with the format:
            projects/{project}/locations/{region}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}
        display_name (str):
            Optional. User friendly name for this
            resource.
        gcp_oracle_zone (str):
            Optional. Google Cloud Platform location
            where Oracle Exadata is hosted.
        entitlement_id (str):
            Output only. Entitlement ID of the private
            offer against which this infrastructure resource
            is provisioned.
        properties (google.cloud.oracledatabase_v1.types.CloudExadataInfrastructureProperties):
            Optional. Various properties of the infra.
        labels (MutableMapping[str, str]):
            Optional. Labels or tags associated with the
            resource.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time that the
            Exadata Infrastructure was created.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    gcp_oracle_zone: str = proto.Field(
        proto.STRING,
        number=8,
    )
    entitlement_id: str = proto.Field(
        proto.STRING,
        number=4,
    )
    properties: "CloudExadataInfrastructureProperties" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="CloudExadataInfrastructureProperties",
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=6,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )


class CloudExadataInfrastructureProperties(proto.Message):
    r"""Various properties of Exadata Infrastructure.

    Attributes:
        ocid (str):
            Output only. OCID of created infra.
            https://docs.oracle.com/en-us/iaas/Content/General/Concepts/identifiers.htm#Oracle
        compute_count (int):
            Optional. The number of compute servers for
            the Exadata Infrastructure.
        storage_count (int):
            Optional. The number of Cloud Exadata storage
            servers for the Exadata Infrastructure.
        total_storage_size_gb (int):
            Optional. The total storage allocated to the
            Exadata Infrastructure resource, in gigabytes
            (GB).
        available_storage_size_gb (int):
            Output only. The available storage can be
            allocated to the Exadata Infrastructure
            resource, in gigabytes (GB).
        maintenance_window (google.cloud.oracledatabase_v1.types.MaintenanceWindow):
            Optional. Maintenance window for repair.
        state (google.cloud.oracledatabase_v1.types.CloudExadataInfrastructureProperties.State):
            Output only. The current lifecycle state of
            the Exadata Infrastructure.
        shape (str):
            Required. The shape of the Exadata
            Infrastructure. The shape determines the amount
            of CPU, storage, and memory resources allocated
            to the instance.
        oci_url (str):
            Output only. Deep link to the OCI console to
            view this resource.
        cpu_count (int):
            Optional. The number of enabled CPU cores.
        max_cpu_count (int):
            Output only. The total number of CPU cores
            available.
        memory_size_gb (int):
            Optional. The memory allocated in GBs.
        max_memory_gb (int):
            Output only. The total memory available in
            GBs.
        db_node_storage_size_gb (int):
            Optional. The local node storage allocated in
            GBs.
        max_db_node_storage_size_gb (int):
            Output only. The total local node storage
            available in GBs.
        data_storage_size_tb (float):
            Output only. Size, in terabytes, of the DATA
            disk group.
        max_data_storage_tb (float):
            Output only. The total available DATA disk
            group size.
        activated_storage_count (int):
            Output only. The requested number of
            additional storage servers activated for the
            Exadata Infrastructure.
        additional_storage_count (int):
            Output only. The requested number of
            additional storage servers for the Exadata
            Infrastructure.
        db_server_version (str):
            Output only. The software version of the
            database servers (dom0) in the Exadata
            Infrastructure.
        storage_server_version (str):
            Output only. The software version of the
            storage servers (cells) in the Exadata
            Infrastructure.
        next_maintenance_run_id (str):
            Output only. The OCID of the next maintenance
            run.
        next_maintenance_run_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the next
            maintenance run will occur.
        next_security_maintenance_run_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the next security
            maintenance run will occur.
        customer_contacts (MutableSequence[google.cloud.oracledatabase_v1.types.CustomerContact]):
            Optional. The list of customer contacts.
        monthly_storage_server_version (str):
            Output only. The monthly software version of
            the storage servers (cells) in the Exadata
            Infrastructure. Example: 20.1.15
        monthly_db_server_version (str):
            Output only. The monthly software version of
            the database servers (dom0) in the Exadata
            Infrastructure. Example: 20.1.15
    """

    class State(proto.Enum):
        r"""The various lifecycle states of the Exadata Infrastructure.

        Values:
            STATE_UNSPECIFIED (0):
                Default unspecified value.
            PROVISIONING (1):
                The Exadata Infrastructure is being
                provisioned.
            AVAILABLE (2):
                The Exadata Infrastructure is available for
                use.
            UPDATING (3):
                The Exadata Infrastructure is being updated.
            TERMINATING (4):
                The Exadata Infrastructure is being
                terminated.
            TERMINATED (5):
                The Exadata Infrastructure is terminated.
            FAILED (6):
                The Exadata Infrastructure is in failed
                state.
            MAINTENANCE_IN_PROGRESS (7):
                The Exadata Infrastructure is in maintenance.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONING = 1
        AVAILABLE = 2
        UPDATING = 3
        TERMINATING = 4
        TERMINATED = 5
        FAILED = 6
        MAINTENANCE_IN_PROGRESS = 7

    ocid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    compute_count: int = proto.Field(
        proto.INT32,
        number=2,
    )
    storage_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    total_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=4,
    )
    available_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=5,
    )
    maintenance_window: "MaintenanceWindow" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="MaintenanceWindow",
    )
    state: State = proto.Field(
        proto.ENUM,
        number=7,
        enum=State,
    )
    shape: str = proto.Field(
        proto.STRING,
        number=8,
    )
    oci_url: str = proto.Field(
        proto.STRING,
        number=9,
    )
    cpu_count: int = proto.Field(
        proto.INT32,
        number=10,
    )
    max_cpu_count: int = proto.Field(
        proto.INT32,
        number=11,
    )
    memory_size_gb: int = proto.Field(
        proto.INT32,
        number=12,
    )
    max_memory_gb: int = proto.Field(
        proto.INT32,
        number=13,
    )
    db_node_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=14,
    )
    max_db_node_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=15,
    )
    data_storage_size_tb: float = proto.Field(
        proto.DOUBLE,
        number=16,
    )
    max_data_storage_tb: float = proto.Field(
        proto.DOUBLE,
        number=17,
    )
    activated_storage_count: int = proto.Field(
        proto.INT32,
        number=18,
    )
    additional_storage_count: int = proto.Field(
        proto.INT32,
        number=19,
    )
    db_server_version: str = proto.Field(
        proto.STRING,
        number=20,
    )
    storage_server_version: str = proto.Field(
        proto.STRING,
        number=21,
    )
    next_maintenance_run_id: str = proto.Field(
        proto.STRING,
        number=22,
    )
    next_maintenance_run_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=23,
        message=timestamp_pb2.Timestamp,
    )
    next_security_maintenance_run_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=24,
        message=timestamp_pb2.Timestamp,
    )
    customer_contacts: MutableSequence[common.CustomerContact] = proto.RepeatedField(
        proto.MESSAGE,
        number=25,
        message=common.CustomerContact,
    )
    monthly_storage_server_version: str = proto.Field(
        proto.STRING,
        number=26,
    )
    monthly_db_server_version: str = proto.Field(
        proto.STRING,
        number=27,
    )


class MaintenanceWindow(proto.Message):
    r"""Maintenance window as defined by Oracle.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/MaintenanceWindow

    Attributes:
        preference (google.cloud.oracledatabase_v1.types.MaintenanceWindow.MaintenanceWindowPreference):
            Optional. The maintenance window scheduling
            preference.
        months (MutableSequence[google.type.month_pb2.Month]):
            Optional. Months during the year when
            maintenance should be performed.
        weeks_of_month (MutableSequence[int]):
            Optional. Weeks during the month when
            maintenance should be performed. Weeks start on
            the 1st, 8th, 15th, and 22nd days of the month,
            and have a duration of 7 days. Weeks start and
            end based on calendar dates, not days of the
            week.
        days_of_week (MutableSequence[google.type.dayofweek_pb2.DayOfWeek]):
            Optional. Days during the week when
            maintenance should be performed.
        hours_of_day (MutableSequence[int]):
            Optional. The window of hours during the day
            when maintenance should be performed. The window
            is a 4 hour slot. Valid values are:

            0 - represents time slot 0:00 - 3:59 UTC
            4 - represents time slot 4:00 - 7:59 UTC
            8 - represents time slot 8:00 - 11:59 UTC
            12 - represents time slot 12:00 - 15:59 UTC
            16 - represents time slot 16:00 - 19:59 UTC
            20 - represents time slot 20:00 - 23:59 UTC
        lead_time_week (int):
            Optional. Lead time window allows user to set
            a lead time to prepare for a down time. The lead
            time is in weeks and valid value is between 1 to
            4.
        patching_mode (google.cloud.oracledatabase_v1.types.MaintenanceWindow.PatchingMode):
            Optional. Cloud CloudExadataInfrastructure
            node patching method, either "ROLLING"
            or "NONROLLING". Default value is ROLLING.
        custom_action_timeout_mins (int):
            Optional. Determines the amount of time the
            system will wait before the start of each
            database server patching operation. Custom
            action timeout is in minutes and valid value is
            between 15 to 120 (inclusive).
        is_custom_action_timeout_enabled (bool):
            Optional. If true, enables the configuration
            of a custom action timeout (waiting period)
            between database server patching operations.
    """

    class MaintenanceWindowPreference(proto.Enum):
        r"""Maintenance window preference.

        Values:
            MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED (0):
                Default unspecified value.
            CUSTOM_PREFERENCE (1):
                Custom preference.
            NO_PREFERENCE (2):
                No preference.
        """
        MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0
        CUSTOM_PREFERENCE = 1
        NO_PREFERENCE = 2

    class PatchingMode(proto.Enum):
        r"""Patching mode.

        Values:
            PATCHING_MODE_UNSPECIFIED (0):
                Default unspecified value.
            ROLLING (1):
                Updates the Cloud Exadata database server
                hosts in a rolling fashion.
            NON_ROLLING (2):
                The non-rolling maintenance method first
                updates your storage servers at the same time,
                then your database servers at the same time.
        """
        PATCHING_MODE_UNSPECIFIED = 0
        ROLLING = 1
        NON_ROLLING = 2

    preference: MaintenanceWindowPreference = proto.Field(
        proto.ENUM,
        number=1,
        enum=MaintenanceWindowPreference,
    )
    months: MutableSequence[month_pb2.Month] = proto.RepeatedField(
        proto.ENUM,
        number=2,
        enum=month_pb2.Month,
    )
    weeks_of_month: MutableSequence[int] = proto.RepeatedField(
        proto.INT32,
        number=3,
    )
    days_of_week: MutableSequence[dayofweek_pb2.DayOfWeek] = proto.RepeatedField(
        proto.ENUM,
        number=4,
        enum=dayofweek_pb2.DayOfWeek,
    )
    hours_of_day: MutableSequence[int] = proto.RepeatedField(
        proto.INT32,
        number=5,
    )
    lead_time_week: int = proto.Field(
        proto.INT32,
        number=6,
    )
    patching_mode: PatchingMode = proto.Field(
        proto.ENUM,
        number=7,
        enum=PatchingMode,
    )
    custom_action_timeout_mins: int = proto.Field(
        proto.INT32,
        number=8,
    )
    is_custom_action_timeout_enabled: bool = proto.Field(
        proto.BOOL,
        number=9,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .autonomous_database import (
    AllConnectionStrings,
    AutonomousDatabase,
    AutonomousDatabaseApex,
    AutonomousDatabaseConnectionStrings,
    AutonomousDatabaseConnectionUrls,
    AutonomousDatabaseProperties,
    AutonomousDatabaseStandbySummary,
    DatabaseConnectionStringProfile,
    DBWorkload,
    GenerateType,
    OperationsInsightsState,
    ScheduledOperationDetails,
    State,
)
from .autonomous_database_character_set import AutonomousDatabaseCharacterSet
from .autonomous_db_backup import (
    AutonomousDatabaseBackup,
    AutonomousDatabaseBackupProperties,
)
from .autonomous_db_version import AutonomousDbVersion
from .common import CustomerContact
from .db_node import DbNode, DbNodeProperties
from .db_server import DbServer, DbServerProperties
from .db_system_shape import DbSystemShape
from .entitlement import CloudAccountDetails, Entitlement
from .exadata_infra import (
    CloudExadataInfrastructure,
    CloudExadataInfrastructureProperties,
    MaintenanceWindow,
)
from .gi_version import GiVersion
from .location_metadata import LocationMetadata
from .oracledatabase import (
    CreateAutonomousDatabaseRequest,
    CreateCloudExadataInfrastructureRequest,
    CreateCloudVmClusterRequest,
    DeleteAutonomousDatabaseRequest,
    DeleteCloudExadataInfrastructureRequest,
    DeleteCloudVmClusterRequest,
    GenerateAutonomousDatabaseWalletRequest,
    GenerateAutonomousDatabaseWalletResponse,
    GetAutonomousDatabaseRequest,
    GetCloudExadataInfrastructureRequest,
    GetCloudVmClusterRequest,
    ListAutonomousDatabaseBackupsRequest,
    ListAutonomousDatabaseBackupsResponse,
    ListAutonomousDatabaseCharacterSetsRequest,
    ListAutonomousDatabaseCharacterSetsResponse,
    ListAutonomousDatabasesRequest,
    ListAutonomousDatabasesResponse,
    ListAutonomousDbVersionsRequest,
    ListAutonomousDbVersionsResponse,
    ListCloudExadataInfrastructuresRequest,
    ListCloudExadataInfrastructuresResponse,
    ListCloudVmClustersRequest,
    ListCloudVmClustersResponse,
    ListDbNodesRequest,
    ListDbNodesResponse,
    ListDbServersRequest,
    ListDbServersResponse,
    ListDbSystemShapesRequest,
    ListDbSystemShapesResponse,
    ListEntitlementsRequest,
    ListEntitlementsResponse,
    ListGiVersionsRequest,
    ListGiVersionsResponse,
    OperationMetadata,
    RestoreAutonomousDatabaseRequest,
)
from .vm_cluster import CloudVmCluster, CloudVmClusterProperties, DataCollectionOptions

__all__ = (
    "AllConnectionStrings",
    "AutonomousDatabase",
    "AutonomousDatabaseApex",
    "AutonomousDatabaseConnectionStrings",
    "AutonomousDatabaseConnectionUrls",
    "AutonomousDatabaseProperties",
    "AutonomousDatabaseStandbySummary",
    "DatabaseConnectionStringProfile",
    "ScheduledOperationDetails",
    "DBWorkload",
    "GenerateType",
    "OperationsInsightsState",
    "State",
    "AutonomousDatabaseCharacterSet",
    "AutonomousDatabaseBackup",
    "AutonomousDatabaseBackupProperties",
    "AutonomousDbVersion",
    "CustomerContact",
    "DbNode",
    "DbNodeProperties",
    "DbServer",
    "DbServerProperties",
    "DbSystemShape",
    "CloudAccountDetails",
    "Entitlement",
    "CloudExadataInfrastructure",
    "CloudExadataInfrastructureProperties",
    "MaintenanceWindow",
    "GiVersion",
    "LocationMetadata",
    "CreateAutonomousDatabaseRequest",
    "CreateCloudExadataInfrastructureRequest",
    "CreateCloudVmClusterRequest",
    "DeleteAutonomousDatabaseRequest",
    "DeleteCloudExadataInfrastructureRequest",
    "DeleteCloudVmClusterRequest",
    "GenerateAutonomousDatabaseWalletRequest",
    "GenerateAutonomousDatabaseWalletResponse",
    "GetAutonomousDatabaseRequest",
    "GetCloudExadataInfrastructureRequest",
    "GetCloudVmClusterRequest",
    "ListAutonomousDatabaseBackupsRequest",
    "ListAutonomousDatabaseBackupsResponse",
    "ListAutonomousDatabaseCharacterSetsRequest",
    "ListAutonomousDatabaseCharacterSetsResponse",
    "ListAutonomousDatabasesRequest",
    "ListAutonomousDatabasesResponse",
    "ListAutonomousDbVersionsRequest",
    "ListAutonomousDbVersionsResponse",
    "ListCloudExadataInfrastructuresRequest",
    "ListCloudExadataInfrastructuresResponse",
    "ListCloudVmClustersRequest",
    "ListCloudVmClustersResponse",
    "ListDbNodesRequest",
    "ListDbNodesResponse",
    "ListDbServersRequest",
    "ListDbServersResponse",
    "ListDbSystemShapesRequest",
    "ListDbSystemShapesResponse",
    "ListEntitlementsRequest",
    "ListEntitlementsResponse",
    "ListGiVersionsRequest",
    "ListGiVersionsResponse",
    "OperationMetadata",
    "RestoreAutonomousDatabaseRequest",
    "CloudVmCluster",
    "CloudVmClusterProperties",
    "DataCollectionOptions",
)
